# Edit Widgets

Namespace: `core/edit-widgets`.

## Selectors

<!-- START TOKEN(Autogenerated selectors|../../../packages/edit-widgets/src/store/selectors.js) -->

### canInsertBlockInWidgetArea

Returns true if a block can be inserted into a widget area.

_Parameters_

-   _state_ `Array`: The open state of the widget areas.
-   _blockName_ `string`: The name of the block being inserted.

_Returns_

-   `boolean`: True if the block can be inserted in a widget area.

### getEditedWidgetAreas

Returns all edited widget area entity records.

_Returns_

-   `Object[]`: List of edited widget area entity records.

### getIsWidgetAreaOpen

Gets whether the widget area is opened.

_Parameters_

-   _state_ `Array`: The open state of the widget areas.
-   _clientId_ `string`: The clientId of the widget area.

_Returns_

-   `boolean`: True if the widget area is open.

### getParentWidgetAreaBlock

Given a child client id, returns the parent widget area block.

_Parameters_

-   _clientId_ `string`: The client id of a block in a widget area.

_Returns_

-   `WPBlock`: The widget area block.

### getReferenceWidgetBlocks

Returns all blocks representing reference widgets.

_Parameters_

-   _referenceWidgetName_ `string`: Optional. If given, only reference widgets with this name will be returned.

_Returns_

-   `Array`: List of all blocks representing reference widgets

### getWidget

Returns API widget data for a particular widget ID.

_Parameters_

-   _id_ `number`: Widget ID.

_Returns_

-   `Object`: API widget data for a particular widget ID.

### getWidgetAreaForWidgetId

Returns widgetArea containing a block identify by given widgetId

_Parameters_

-   _widgetId_ `string`: The ID of the widget.

_Returns_

-   `Object`: Containing widget area.

### getWidgetAreas

Returns all API widget areas.

_Returns_

-   `Object[]`: API List of widget areas.

### getWidgets

Returns all API widgets.

_Returns_

-   `Object[]`: API List of widgets.

### isInserterOpened

Returns true if the inserter is opened.

_Parameters_

-   _state_ `Object`: Global application state.

_Returns_

-   `boolean`: Whether the inserter is opened.

### isListViewOpened

Returns true if the list view is opened.

_Parameters_

-   _state_ `Object`: Global application state.

_Returns_

-   `boolean`: Whether the list view is opened.

### isSavingWidgetAreas

Returns true if any widget area is currently being saved.

_Returns_

-   `boolean`: True if any widget area is currently being saved. False otherwise.

<!-- END TOKEN(Autogenerated selectors|../../../packages/edit-widgets/src/store/selectors.js) -->

## Actions

<!-- START TOKEN(Autogenerated actions|../../../packages/edit-widgets/src/store/actions.js) -->

### closeGeneralSidebar

Returns an action object signalling that the user closed the sidebar.

_Returns_

-   `Object`: Action creator.

### moveBlockToWidgetArea

Action that handles moving a block between widget areas

_Parameters_

-   _clientId_ `string`: The clientId of the block to move.
-   _widgetAreaId_ `string`: The id of the widget area to move the block to.

### persistStubPost

Persists a stub post with given ID to core data store. The post is meant to be in-memory only and shouldn't be saved via the API.

_Parameters_

-   _id_ `string`: Post ID.
-   _blocks_ `Array`: Blocks the post should consist of.

_Returns_

-   `Object`: The post object.

### saveEditedWidgetAreas

Converts all the blocks from edited widget areas into widgets, and submits a batch request to save everything at once.

Creates a snackbar notice on either success or error.

_Returns_

-   `Function`: An action creator.

### saveWidgetArea

Converts all the blocks from a widget area specified by ID into widgets, and submits a batch request to save everything at once.

_Parameters_

-   _widgetAreaId_ `string`: ID of the widget area to process.

_Returns_

-   `Function`: An action creator.

### saveWidgetAreas

Converts all the blocks from specified widget areas into widgets, and submits a batch request to save everything at once.

_Parameters_

-   _widgetAreas_ `Object[]`: Widget areas to save.

_Returns_

-   `Function`: An action creator.

### setIsInserterOpened

Returns an action object used to open/close the inserter.

_Parameters_

-   _value_ `boolean|Object`: Whether the inserter should be opened (true) or closed (false). To specify an insertion point, use an object.
-   _value.rootClientId_ `string`: The root client ID to insert at.
-   _value.insertionIndex_ `number`: The index to insert at.

_Returns_

-   `Object`: Action object.

### setIsListViewOpened

Returns an action object used to open/close the list view.

_Parameters_

-   _isOpen_ `boolean`: A boolean representing whether the list view should be opened or closed.

_Returns_

-   `Object`: Action object.

### setIsWidgetAreaOpen

Sets the open state of the widget area.

_Parameters_

-   _clientId_ `string`: The clientId of the widget area.
-   _isOpen_ `boolean`: Whether the widget area should be opened.

_Returns_

-   `Object`: Action.

### setWidgetAreasOpenState

Sets the open state of all the widget areas.

_Parameters_

-   _widgetAreasOpenState_ `Object`: The open states of all the widget areas.

_Returns_

-   `Object`: Action.

### setWidgetIdForClientId

Sets the clientId stored for a particular widgetId.

_Parameters_

-   _clientId_ `number`: Client id.
-   _widgetId_ `number`: Widget id.

_Returns_

-   `Object`: Action.

<!-- END TOKEN(Autogenerated actions|../../../packages/edit-widgets/src/store/actions.js) -->
